﻿using Entities;
using Model.OrderCriteria;
using Shared;

namespace API.Service;

public class InquiryDataServiceApi(IInquiryService<InquiryEntity> inquiryService) : IInquiryService<InquiryEntity>
{
    public Task<InquiryEntity?> AddItem(InquiryEntity? item)
    {
        return inquiryService.AddItem(item);
    }
    public InquiryEntity CreateInquiry(string title, string description, bool isUser)
    {
        return inquiryService.CreateInquiry(title, description, isUser);
    }

    public bool DeleteInquiry(int id)
    {
        return inquiryService.DeleteInquiry(id);
    }

    public Task<bool> DeleteItem(int id)
    {
        return inquiryService.DeleteItem(id);
    }

    public IEnumerable<InquiryEntity> GetInquiries(int page, int number, InquiryOrderCriteria orderCriteria)
    {
        var inquiries = inquiryService.GetInquiries(page, number, orderCriteria);
        return inquiries.Select(i => i).ToList();
    }

    public InquiryEntity GetInquiryById(int id) => inquiryService.GetInquiryById(id);

    public InquiryEntity GetInquiryByTitle(string title) => inquiryService.GetInquiryByTitle(title);

    public Task<IEnumerable<InquiryEntity>> GetItems(int page, int count, object? orderCriteria = null, string? filter = null, object? valueFilter = null)
    {
        return inquiryService.GetItems(page, count, orderCriteria, filter, valueFilter);
    }

    public InquiryEntity UpdateInquiry(int id, InquiryEntity inquiry)
    {
        return inquiryService.UpdateInquiry(id, inquiry);
    }

    public Task<InquiryEntity> UpdateItem<TDto>(int? id, TDto? newItem) where TDto : class
    {
        return inquiryService.UpdateItem<TDto>(id, newItem);
    }
}