﻿using Entities;
using Model.OrderCriteria;
using Shared;

namespace API.Service;

public class LessonDataServiceApi(ILessonService<LessonEntity> lessonService) : ILessonService<LessonEntity>
{
    public IEnumerable<LessonEntity> GetLessons(int page, int number, LessonOrderCriteria orderCriteria)
    {
        var lessonsEntities = lessonService.GetLessons(page, number, orderCriteria);
        return lessonsEntities.Select(e => e).ToList();
    }

    public LessonEntity GetLessonById(int id) => lessonService.GetLessonById(id);

    public LessonEntity GetLessonByTitle(string title) => lessonService.GetLessonByTitle(title);

    public bool DeleteLesson(int id) => lessonService.DeleteLesson(id);

    public LessonEntity UpdateLesson(int id, LessonEntity lesson) =>
        lessonService.UpdateLesson(id, lesson);

    public LessonEntity CreateLesson(string title, string lastPublisher, DateOnly? lastEdit) =>
        lessonService.CreateLesson(title, lastPublisher, lastEdit);

    public Task<LessonEntity?> AddItem(LessonEntity? item)
    {
       return lessonService.AddItem(item);
    }

    public Task<bool> DeleteItem(int id)
    {
        return lessonService.DeleteItem(id);
    }

    public Task<LessonEntity> UpdateItem<TDto>(int? id, TDto? newItem) where TDto : class
    {
        return lessonService.UpdateItem(id, newItem);
    }

    public Task<IEnumerable<LessonEntity>> GetItems(int page, int count, object? orderCriteria = null, string? filter = null, object? valueFilter = null)
    {
        return lessonService.GetItems(page, count, orderCriteria, filter, valueFilter);
    }
}